EXPORTS
	??0RMMFDevSoundProxy@@QAE@XZ @ 1 NONAME ; RMMFDevSoundProxy::RMMFDevSoundProxy(void)
	?AsyncCustomCommand@RMMFDevSoundProxy@@QAEXVTUid@@AAVTRequestStatus@@ABVTDesC8@@2PAVTDes8@@@Z @ 2 NONAME ; void RMMFDevSoundProxy::AsyncCustomCommand(class TUid, class TRequestStatus &, class TDesC8 const &, class TDesC8 const &, class TDes8 *)
	?BufferToBeEmptiedData@RMMFDevSoundProxy@@QAEHAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@@Z @ 3 NONAME ; int RMMFDevSoundProxy::BufferToBeEmptiedData(class TPckgBuf<class TMMFDevSoundProxyHwBuf> &)
	?BufferToBeFilledData@RMMFDevSoundProxy@@QAEHAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@@Z @ 4  NONAME ABSENT ; int RMMFDevSoundProxy::BufferToBeFilledData(class TPckgBuf<class TMMFDevSoundProxyHwBuf> &) 
	?CancelInitialize@RMMFDevSoundProxy@@UAEHXZ @ 5 NONAME ; int RMMFDevSoundProxy::CancelInitialize(void)
	?CancelRegisterAsClient@RMMFDevSoundProxy@@QAEHVTUid@@@Z @ 6 NONAME ; int RMMFDevSoundProxy::CancelRegisterAsClient(class TUid)
	?Capabilities@RMMFDevSoundProxy@@QAE?AVTMMFCapabilities@@XZ @ 7 NONAME ; class TMMFCapabilities RMMFDevSoundProxy::Capabilities(void)
	?Close@RMMFDevSoundProxy@@QAEXXZ @ 8 NONAME ; void RMMFDevSoundProxy::Close(void)
	?Config@RMMFDevSoundProxy@@QAE?AVTMMFCapabilities@@XZ @ 9 NONAME ; class TMMFCapabilities RMMFDevSoundProxy::Config(void)
	?CustomCommandAsync@RMMFDevSoundProxy@@UAEXABV?$TPckgBuf@VTMMFMessageDestination@@@@HABVTDesC8@@1AAVTDes8@@AAVTRequestStatus@@@Z @ 10 NONAME ; void RMMFDevSoundProxy::CustomCommandAsync(class TPckgBuf<class TMMFMessageDestination> const &, int, class TDesC8 const &, class TDesC8 const &, class TDes8 &, class TRequestStatus &)
	?CustomCommandAsync@RMMFDevSoundProxy@@UAEXABV?$TPckgBuf@VTMMFMessageDestination@@@@HABVTDesC8@@1AAVTRequestStatus@@@Z @ 11 NONAME ; void RMMFDevSoundProxy::CustomCommandAsync(class TPckgBuf<class TMMFMessageDestination> const &, int, class TDesC8 const &, class TDesC8 const &, class TRequestStatus &)
	?CustomCommandSync@RMMFDevSoundProxy@@UAEHABV?$TPckgBuf@VTMMFMessageDestination@@@@HABVTDesC8@@1@Z @ 12 NONAME ; int RMMFDevSoundProxy::CustomCommandSync(class TPckgBuf<class TMMFMessageDestination> const &, int, class TDesC8 const &, class TDesC8 const &)
	?CustomCommandSync@RMMFDevSoundProxy@@UAEHABV?$TPckgBuf@VTMMFMessageDestination@@@@HABVTDesC8@@1AAVTDes8@@@Z @ 13 NONAME ; int RMMFDevSoundProxy::CustomCommandSync(class TPckgBuf<class TMMFMessageDestination> const &, int, class TDesC8 const &, class TDesC8 const &, class TDes8 &)
	?CustomInterface@RMMFDevSoundProxy@@QAEPAXVTUid@@@Z @ 14 NONAME ; void * RMMFDevSoundProxy::CustomInterface(class TUid)
	?EmptyBuffers@RMMFDevSoundProxy@@QAEHXZ @ 15 NONAME ; int RMMFDevSoundProxy::EmptyBuffers(void)
	?FixedSequenceCount@RMMFDevSoundProxy@@QAEHXZ @ 16 NONAME ; int RMMFDevSoundProxy::FixedSequenceCount(void)
	?FixedSequenceName@RMMFDevSoundProxy@@QAEABVTDesC16@@H@Z @ 17 NONAME ; class TDesC16 const & RMMFDevSoundProxy::FixedSequenceName(int)
	?Gain@RMMFDevSoundProxy@@QAEHXZ @ 18 NONAME ; int RMMFDevSoundProxy::Gain(void)
	?GetPlayBalanceL@RMMFDevSoundProxy@@QAEXAAH0@Z @ 19 NONAME ; void RMMFDevSoundProxy::GetPlayBalanceL(int &, int &)
	?GetRecordBalanceL@RMMFDevSoundProxy@@QAEXAAH0@Z @ 20 NONAME ; void RMMFDevSoundProxy::GetRecordBalanceL(int &, int &)
	?GetResourceNotificationData@RMMFDevSoundProxy@@QAEHVTUid@@AAVTDes8@@@Z @ 21 NONAME ; int RMMFDevSoundProxy::GetResourceNotificationData(class TUid, class TDes8 &)
	?GetSupportedInputDataTypesL@RMMFDevSoundProxy@@QAEXAAV?$RArray@VTFourCC@@@@ABVTMMFPrioritySettings@@@Z @ 22 NONAME ; void RMMFDevSoundProxy::GetSupportedInputDataTypesL(class RArray<class TFourCC> &, class TMMFPrioritySettings const &)
	?GetSupportedOutputDataTypesL@RMMFDevSoundProxy@@QAEXAAV?$RArray@VTFourCC@@@@ABVTMMFPrioritySettings@@@Z @ 23 NONAME ; void RMMFDevSoundProxy::GetSupportedOutputDataTypesL(class RArray<class TFourCC> &, class TMMFPrioritySettings const &)
	?InitializeL@RMMFDevSoundProxy@@QAEXAAVMDevSoundObserver@@VTFourCC@@W4TMMFState@@AAVMMMFDevSoundCustomInterfaceObserver@@@Z @ 24 NONAME ; void RMMFDevSoundProxy::InitializeL(class MDevSoundObserver &, class TFourCC, enum TMMFState, class MMMFDevSoundCustomInterfaceObserver &)
	?InitializeL@RMMFDevSoundProxy@@QAEXAAVMDevSoundObserver@@VTUid@@W4TMMFState@@AAVMMMFDevSoundCustomInterfaceObserver@@@Z @ 25 NONAME ; void RMMFDevSoundProxy::InitializeL(class MDevSoundObserver &, class TUid, enum TMMFState, class MMMFDevSoundCustomInterfaceObserver &)
	?InitializeL@RMMFDevSoundProxy@@QAEXAAVMDevSoundObserver@@W4TMMFState@@AAVMMMFDevSoundCustomInterfaceObserver@@@Z @ 26 NONAME ; void RMMFDevSoundProxy::InitializeL(class MDevSoundObserver &, enum TMMFState, class MMMFDevSoundCustomInterfaceObserver &)
	?MaxGain@RMMFDevSoundProxy@@QAEHXZ @ 27 NONAME ; int RMMFDevSoundProxy::MaxGain(void)
	?MaxVolume@RMMFDevSoundProxy@@QAEHXZ @ 28 NONAME ; int RMMFDevSoundProxy::MaxVolume(void)
	?Open@RMMFDevSoundProxy@@QAEHXZ @ 29 NONAME ; int RMMFDevSoundProxy::Open(void)
	?Pause@RMMFDevSoundProxy@@QAEXXZ @ 30 NONAME ; void RMMFDevSoundProxy::Pause(void)
	?PlayDTMFStringL@RMMFDevSoundProxy@@QAEXABVTDesC16@@@Z @ 31 NONAME ; void RMMFDevSoundProxy::PlayDTMFStringL(class TDesC16 const &)
	?PlayData@RMMFDevSoundProxy@@QAEXXZ @ 32 NONAME ; void RMMFDevSoundProxy::PlayData(void)
	?PlayDualToneL@RMMFDevSoundProxy@@QAEXHHABVTTimeIntervalMicroSeconds@@@Z @ 33 NONAME ; void RMMFDevSoundProxy::PlayDualToneL(int, int, class TTimeIntervalMicroSeconds const &)
	?PlayFixedSequenceL@RMMFDevSoundProxy@@QAEXH@Z @ 34 NONAME ; void RMMFDevSoundProxy::PlayFixedSequenceL(int)
	?PlayInitL@RMMFDevSoundProxy@@QAEXXZ @ 35 NONAME ; void RMMFDevSoundProxy::PlayInitL(void)
	?PlayToneL@RMMFDevSoundProxy@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 36 NONAME ; void RMMFDevSoundProxy::PlayToneL(int, class TTimeIntervalMicroSeconds const &)
	?PlayToneSequenceL@RMMFDevSoundProxy@@QAEXABVTDesC8@@@Z @ 37 NONAME ; void RMMFDevSoundProxy::PlayToneSequenceL(class TDesC8 const &)
	?PostOpen@RMMFDevSoundProxy@@QAEHXZ @ 38 NONAME ; int RMMFDevSoundProxy::PostOpen(void)
	?RecordData@RMMFDevSoundProxy@@QAEXXZ @ 39 NONAME ; void RMMFDevSoundProxy::RecordData(void)
	?RecordInitL@RMMFDevSoundProxy@@QAEXXZ @ 40 NONAME ; void RMMFDevSoundProxy::RecordInitL(void)
	?RegisterAsClient@RMMFDevSoundProxy@@QAEHVTUid@@ABVTDesC8@@@Z @ 41 NONAME ; int RMMFDevSoundProxy::RegisterAsClient(class TUid, class TDesC8 const &)
	?SamplesPlayed@RMMFDevSoundProxy@@QAEHXZ @ 42 NONAME ; int RMMFDevSoundProxy::SamplesPlayed(void)
	?SamplesRecorded@RMMFDevSoundProxy@@QAEHXZ @ 43 NONAME ; int RMMFDevSoundProxy::SamplesRecorded(void)
	?SetBuffer@RMMFDevSoundProxy@@QAEXPAVCMMFDataBuffer@@@Z @ 44 NONAME ABSENT ; void RMMFDevSoundProxy::SetBuffer(class CMMFDataBuffer *)
	?SetConfigL@RMMFDevSoundProxy@@QAEXABVTMMFCapabilities@@@Z @ 45 NONAME ; void RMMFDevSoundProxy::SetConfigL(class TMMFCapabilities const &)
	?SetDTMFLengths@RMMFDevSoundProxy@@QAEXAAVTTimeIntervalMicroSeconds32@@00@Z @ 46 NONAME ; void RMMFDevSoundProxy::SetDTMFLengths(class TTimeIntervalMicroSeconds32 &, class TTimeIntervalMicroSeconds32 &, class TTimeIntervalMicroSeconds32 &)
	?SetDevSoundInfo@RMMFDevSoundProxy@@QAEHXZ @ 47 NONAME ; int RMMFDevSoundProxy::SetDevSoundInfo(void)
	?SetGain@RMMFDevSoundProxy@@QAEHH@Z @ 48 NONAME ; int RMMFDevSoundProxy::SetGain(int)
	?SetPlayBalanceL@RMMFDevSoundProxy@@QAEXHH@Z @ 49 NONAME ; void RMMFDevSoundProxy::SetPlayBalanceL(int, int)
	?SetPrioritySettings@RMMFDevSoundProxy@@QAEXABVTMMFPrioritySettings@@@Z @ 50 NONAME ; void RMMFDevSoundProxy::SetPrioritySettings(class TMMFPrioritySettings const &)
	?SetRecordBalanceL@RMMFDevSoundProxy@@QAEXHH@Z @ 51 NONAME ; void RMMFDevSoundProxy::SetRecordBalanceL(int, int)
	?SetToneRepeats@RMMFDevSoundProxy@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 52 NONAME ; void RMMFDevSoundProxy::SetToneRepeats(int, class TTimeIntervalMicroSeconds const &)
	?SetVolume@RMMFDevSoundProxy@@QAEHH@Z @ 53 NONAME ; int RMMFDevSoundProxy::SetVolume(int)
	?SetVolumeRamp@RMMFDevSoundProxy@@QAEXABVTTimeIntervalMicroSeconds@@@Z @ 54 NONAME ; void RMMFDevSoundProxy::SetVolumeRamp(class TTimeIntervalMicroSeconds const &)
	?Stop@RMMFDevSoundProxy@@QAEXXZ @ 55 NONAME ; void RMMFDevSoundProxy::Stop(void)
	?SyncCustomCommand@RMMFDevSoundProxy@@QAEHVTUid@@ABVTDesC8@@1PAVTDes8@@@Z @ 56 NONAME ; int RMMFDevSoundProxy::SyncCustomCommand(class TUid, class TDesC8 const &, class TDesC8 const &, class TDes8 *)
	?Volume@RMMFDevSoundProxy@@QAEHXZ @ 57 NONAME ; int RMMFDevSoundProxy::Volume(void)
	?WillResumePlay@RMMFDevSoundProxy@@QAEHXZ @ 58 NONAME ; int RMMFDevSoundProxy::WillResumePlay(void)
	?GetTimePlayed@RMMFDevSoundProxy@@QAEHAAVTTimeIntervalMicroSeconds@@@Z @ 59 NONAME ; int RMMFDevSoundProxy::GetTimePlayed(class TTimeIntervalMicroSeconds &)
	?SetClientThreadInfo@RMMFDevSoundProxy@@QAEHAAVTThreadId@@@Z @ 60 NONAME ; int RMMFDevSoundProxy::SetClientThreadInfo(class TThreadId &)
	?IsResumeSupported@RMMFDevSoundProxy@@QAEHXZ @ 61 NONAME ; int RMMFDevSoundProxy::IsResumeSupported(void)
	?Resume@RMMFDevSoundProxy@@QAEHXZ @ 62 NONAME ; int RMMFDevSoundProxy::Resume(void)
	?BufferToBeFilledData@RMMFDevSoundProxy@@QAEHHAAV?$TPckgBuf@VTMMFDevSoundProxyHwBuf@@@@@Z @ 63  NONAME ; int RMMFDevSoundProxy::BufferToBeFilledData(int, class TPckgBuf<class TMMFDevSoundProxyHwBuf> &)

